@@ -16,6 +16,7 @@
 #include "passmanager.h"
 #include "pkpassmanager.h"
 #include "reservationmanager.h"
+#include "settings.h"
 #include "transfermanager.h"
 #include "tripgroupmanager.h"
 
@@ -196,8 +197,12 @@ private Q_SLOTS:
 
         LiveDataManager liveDataMgr;
 
+        Settings settings;
+        settings.setHomeCountryIsoCode(u"XX"_s);
+
         ApplicationController appController;
         QSignalSpy infoSpy(&appController, &ApplicationController::infoMessage);
+        QSignalSpy settingsReloadSpy(&appController, &ApplicationController::reloadSettings);
         appController.setPkPassManager(&pkPassMgr);
         appController.setReservationManager(&resMgr);
         appController.setDocumentManager(&docMgr);
@@ -244,6 +249,7 @@ private Q_SLOTS:
         QCOMPARE(pkPassMgr.passes().size(), 1);
         QCOMPARE(passMgr.rowCount(), 1);
         QCOMPARE(infoSpy.size(), 2);
+        QCOMPARE(settingsReloadSpy.size(), 1);
 
         Test::clearAll(&pkPassMgr);
         Test::clearAll(&resMgr);
@@ -259,6 +265,7 @@ private Q_SLOTS:
         QCOMPARE(pkPassMgr.passes().size(), 1);
         QCOMPARE(passMgr.rowCount(), 1);
         QCOMPARE(infoSpy.size(), 3);
+        QCOMPARE(settingsReloadSpy.size(), 2);
     }
 
     void testExportTripGroup()
