@@ -191,8 +191,9 @@ void WeatherForecastManager::fetchNext()
     req.setAttribute(QNetworkRequest::User, QVariant::fromValue(tile));
 
     // see §Identification on https://api.met.no/conditions_service.html
-    req.setHeader(QNetworkRequest::UserAgentHeader, QString(QCoreApplication::applicationName() +
-        QLatin1Char(' ') + QCoreApplication::applicationVersion() + QLatin1StringView(" (kde-pim@kde.org)")));
+    req.setHeader(
+        QNetworkRequest::UserAgentHeader,
+        QString(QCoreApplication::applicationName() + QLatin1Char(' ') + QCoreApplication::applicationVersion() + QLatin1StringView(" (kde-pim@kde.org)")));
     // TODO see §Cache on https://api.met.no/conditions_service.html
     // see §Compression on https://api.met.no/conditions_service.html
     req.setRawHeader("Accept-Encoding", "gzip");
@@ -221,15 +222,13 @@ void WeatherForecastManager::tileDownloaded()
 
 QString WeatherForecastManager::cachePath(WeatherTile tile) const
 {
-    const auto path = QString(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)
-        + QLatin1StringView("/weather/")
-        + QString::number(tile.lat) + QLatin1Char('/')
-        + QString::number(tile.lon) + QLatin1Char('/'));
+    const auto path = QString(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1StringView("/weather/") + QString::number(tile.lat)
+                              + QLatin1Char('/') + QString::number(tile.lon) + QLatin1Char('/'));
     QDir().mkpath(path);
     return path;
 }
 
-void WeatherForecastManager::writeToCacheFile(QNetworkReply* reply) const
+void WeatherForecastManager::writeToCacheFile(QNetworkReply *reply) const
 {
     const auto tile = reply->request().attribute(QNetworkRequest::User).value<WeatherTile>();
     qDebug() << tile.lat << tile.lon;
@@ -255,7 +254,7 @@ void WeatherForecastManager::writeToCacheFile(QNetworkReply* reply) const
         stream.zfree = nullptr;
         stream.opaque = nullptr;
         stream.avail_in = data.size();
-        stream.next_in = reinterpret_cast<unsigned char*>(const_cast<char*>(data.data()));
+        stream.next_in = reinterpret_cast<unsigned char *>(const_cast<char *>(data.data()));
 
         auto ret = inflateInit2(&stream, 15 + 32); // see docs, the magic numbers enable gzip decoding
         if (ret != Z_OK) {
@@ -273,7 +272,7 @@ void WeatherForecastManager::writeToCacheFile(QNetworkReply* reply) const
                 break;
             }
 
-            f.write(reinterpret_cast<char*>(buffer), sizeof(buffer) - stream.avail_out);
+            f.write(reinterpret_cast<char *>(buffer), sizeof(buffer) - stream.avail_out);
         } while (stream.avail_out == 0);
         inflateEnd(&stream);
     } else {
@@ -306,7 +305,7 @@ bool WeatherForecastManager::loadForecastData(WeatherTile tile) const
     return true;
 }
 
-void WeatherForecastManager::mergeForecasts(std::vector<WeatherForecast>& forecasts) const
+void WeatherForecastManager::mergeForecasts(std::vector<WeatherForecast> &forecasts) const
 {
     std::stable_sort(forecasts.begin(), forecasts.end(), [](const WeatherForecast &lhs, const WeatherForecast &rhs) {
         if (lhs.dateTime() == rhs.dateTime())
@@ -387,47 +386,47 @@ struct symbol_map_t {
 };
 
 static const symbol_map_t symbol_map[] = {
-    {  1, WeatherForecast::Clear }, // 1 Sun
-    {  2, WeatherForecast::Clear | WeatherForecast::LightClouds }, // 2 LightCloud
-    {  3, WeatherForecast::Clear | WeatherForecast::Clouds }, // 3 PartlyCloud
-    {  4, WeatherForecast::Clouds }, // 4 Cloud
-    {  5, WeatherForecast::Clear | WeatherForecast::LightRain }, // 5 LightRainSun
-    {  6, WeatherForecast::Clear | WeatherForecast::LightRain | WeatherForecast::ThunderStorm }, // 6 LightRainThunderSun
-    {  7, WeatherForecast::Clear | WeatherForecast::Hail }, // 7 SleetSun
-    {  8, WeatherForecast::Clear | WeatherForecast::Snow }, // 8 SnowSun
-    {  9, WeatherForecast::LightRain }, // 9 LightRain
-    { 10, WeatherForecast::Rain }, // 10 Rain
-    { 11, WeatherForecast::Rain | WeatherForecast::ThunderStorm }, // 11 RainThunder
-    { 12, WeatherForecast::Hail }, // 12 Sleet
-    { 13, WeatherForecast::Snow }, // 13 Snow
-    { 14, WeatherForecast::Snow | WeatherForecast::ThunderStorm }, // 14 SnowThunder
-    { 15, WeatherForecast::Fog }, // 15 Fog
-    { 20, WeatherForecast::Clear | WeatherForecast::Hail | WeatherForecast::ThunderStorm }, // 20 SleetSunThunder
-    { 21, WeatherForecast::Clear | WeatherForecast::Snow | WeatherForecast::ThunderStorm }, // 21 SnowSunThunder
-    { 22, WeatherForecast::LightRain | WeatherForecast::ThunderStorm }, // 22 LightRainThunder
-    { 23, WeatherForecast::Hail | WeatherForecast::ThunderStorm }, // 23 SleetThunder
-    { 24, WeatherForecast::Clear | WeatherForecast::LightRain | WeatherForecast::ThunderStorm }, // 24 DrizzleThunderSun
-    { 25, WeatherForecast::Clear | WeatherForecast::Rain | WeatherForecast::ThunderStorm }, // 25 RainThunderSun
-    { 26, WeatherForecast::Clear | WeatherForecast::Hail | WeatherForecast::ThunderStorm }, // 26 LightSleetThunderSun
-    { 27, WeatherForecast::Clear | WeatherForecast::Hail | WeatherForecast::ThunderStorm }, // 27 HeavySleetThunderSun
-    { 28, WeatherForecast::Clear |  WeatherForecast::LightSnow | WeatherForecast::ThunderStorm }, // 28 LightSnowThunderSun
-    { 29, WeatherForecast::Clear | WeatherForecast::Snow | WeatherForecast::ThunderStorm }, // 29 HeavySnowThunderSun
-    { 30, WeatherForecast::LightRain | WeatherForecast::ThunderStorm }, // 30 DrizzleThunder
-    { 31, WeatherForecast::Hail | WeatherForecast::ThunderStorm }, // 31 LightSleetThunder
-    { 32, WeatherForecast::Hail | WeatherForecast::ThunderStorm }, // 32 HeavySleetThunder
-    { 33, WeatherForecast::LightSnow | WeatherForecast::ThunderStorm }, // 33 LightSnowThunder
-    { 34, WeatherForecast::Snow | WeatherForecast::ThunderStorm }, // 34 HeavySnowThunder
-    { 40, WeatherForecast::Clear | WeatherForecast::LightRain }, // 40 DrizzleSun
-    { 41, WeatherForecast::Clear | WeatherForecast::Rain}, // 41 RainSun
-    { 42, WeatherForecast::Clear | WeatherForecast::Hail }, // 42 LightSleetSun
-    { 43, WeatherForecast::Clear | WeatherForecast::Hail }, // 43 HeavySleetSun
-    { 44, WeatherForecast::Clear | WeatherForecast::LightSnow }, // 44 LightSnowSun
-    { 45, WeatherForecast::Clear | WeatherForecast::Snow }, // 45 HeavysnowSun
-    { 46, WeatherForecast::LightRain }, // 46 Drizzle
-    { 47, WeatherForecast::Hail }, // 47 LightSleet
-    { 48, WeatherForecast::Hail }, // 48 HeavySleet
-    { 49, WeatherForecast::LightSnow }, // 49 LightSnow
-    { 50, WeatherForecast::Snow } // 50 HeavySnow
+    {1, WeatherForecast::Clear}, // 1 Sun
+    {2, WeatherForecast::Clear | WeatherForecast::LightClouds}, // 2 LightCloud
+    {3, WeatherForecast::Clear | WeatherForecast::Clouds}, // 3 PartlyCloud
+    {4, WeatherForecast::Clouds}, // 4 Cloud
+    {5, WeatherForecast::Clear | WeatherForecast::LightRain}, // 5 LightRainSun
+    {6, WeatherForecast::Clear | WeatherForecast::LightRain | WeatherForecast::ThunderStorm}, // 6 LightRainThunderSun
+    {7, WeatherForecast::Clear | WeatherForecast::Hail}, // 7 SleetSun
+    {8, WeatherForecast::Clear | WeatherForecast::Snow}, // 8 SnowSun
+    {9, WeatherForecast::LightRain}, // 9 LightRain
+    {10, WeatherForecast::Rain}, // 10 Rain
+    {11, WeatherForecast::Rain | WeatherForecast::ThunderStorm}, // 11 RainThunder
+    {12, WeatherForecast::Hail}, // 12 Sleet
+    {13, WeatherForecast::Snow}, // 13 Snow
+    {14, WeatherForecast::Snow | WeatherForecast::ThunderStorm}, // 14 SnowThunder
+    {15, WeatherForecast::Fog}, // 15 Fog
+    {20, WeatherForecast::Clear | WeatherForecast::Hail | WeatherForecast::ThunderStorm}, // 20 SleetSunThunder
+    {21, WeatherForecast::Clear | WeatherForecast::Snow | WeatherForecast::ThunderStorm}, // 21 SnowSunThunder
+    {22, WeatherForecast::LightRain | WeatherForecast::ThunderStorm}, // 22 LightRainThunder
+    {23, WeatherForecast::Hail | WeatherForecast::ThunderStorm}, // 23 SleetThunder
+    {24, WeatherForecast::Clear | WeatherForecast::LightRain | WeatherForecast::ThunderStorm}, // 24 DrizzleThunderSun
+    {25, WeatherForecast::Clear | WeatherForecast::Rain | WeatherForecast::ThunderStorm}, // 25 RainThunderSun
+    {26, WeatherForecast::Clear | WeatherForecast::Hail | WeatherForecast::ThunderStorm}, // 26 LightSleetThunderSun
+    {27, WeatherForecast::Clear | WeatherForecast::Hail | WeatherForecast::ThunderStorm}, // 27 HeavySleetThunderSun
+    {28, WeatherForecast::Clear | WeatherForecast::LightSnow | WeatherForecast::ThunderStorm}, // 28 LightSnowThunderSun
+    {29, WeatherForecast::Clear | WeatherForecast::Snow | WeatherForecast::ThunderStorm}, // 29 HeavySnowThunderSun
+    {30, WeatherForecast::LightRain | WeatherForecast::ThunderStorm}, // 30 DrizzleThunder
+    {31, WeatherForecast::Hail | WeatherForecast::ThunderStorm}, // 31 LightSleetThunder
+    {32, WeatherForecast::Hail | WeatherForecast::ThunderStorm}, // 32 HeavySleetThunder
+    {33, WeatherForecast::LightSnow | WeatherForecast::ThunderStorm}, // 33 LightSnowThunder
+    {34, WeatherForecast::Snow | WeatherForecast::ThunderStorm}, // 34 HeavySnowThunder
+    {40, WeatherForecast::Clear | WeatherForecast::LightRain}, // 40 DrizzleSun
+    {41, WeatherForecast::Clear | WeatherForecast::Rain}, // 41 RainSun
+    {42, WeatherForecast::Clear | WeatherForecast::Hail}, // 42 LightSleetSun
+    {43, WeatherForecast::Clear | WeatherForecast::Hail}, // 43 HeavySleetSun
+    {44, WeatherForecast::Clear | WeatherForecast::LightSnow}, // 44 LightSnowSun
+    {45, WeatherForecast::Clear | WeatherForecast::Snow}, // 45 HeavysnowSun
+    {46, WeatherForecast::LightRain}, // 46 Drizzle
+    {47, WeatherForecast::Hail}, // 47 LightSleet
+    {48, WeatherForecast::Hail}, // 48 HeavySleet
+    {49, WeatherForecast::LightSnow}, // 49 LightSnow
+    {50, WeatherForecast::Snow} // 50 HeavySnow
 };
 
 WeatherForecast WeatherForecastManager::parseForecastElement(QXmlStreamReader &reader) const
@@ -435,39 +434,39 @@ WeatherForecast WeatherForecastManager::parseForecastElement(QXmlStreamReader &r
     WeatherForecast fc;
     while (!reader.atEnd()) {
         switch (reader.tokenType()) {
-            case QXmlStreamReader::StartElement:
-                if (reader.name() == QLatin1StringView("temperature")) {
-                    const auto t = reader.attributes().value(QLatin1StringView("value")).toFloat();
-                    fc.setMinimumTemperature(t);
-                    fc.setMaximumTemperature(t);
-                } else if (reader.name() == QLatin1StringView("minTemperature")) {
-                    fc.setMinimumTemperature(reader.attributes().value(QLatin1StringView("value")).toFloat());
-                } else if (reader.name() == QLatin1StringView("maxTemperature")) {
-                    fc.setMaximumTemperature(reader.attributes().value(QLatin1StringView("value")).toFloat());
-                } else if (reader.name() == QLatin1StringView("windSpeed")) {
-                    fc.setWindSpeed(reader.attributes().value(QLatin1StringView("mps")).toFloat());
-                } else if (reader.name() == QLatin1StringView("symbol")) {
-                    auto symId = reader.attributes().value(QLatin1StringView("number")).toInt();
-                    if (symId > 100) {
-                        symId -= 100; // map polar night symbols
-                    }
-                    const auto it = std::lower_bound(std::begin(symbol_map), std::end(symbol_map), symId, [](symbol_map_t lhs, uint8_t rhs) {
-                        return lhs.id < rhs;
-                    });
-                    if (it != std::end(symbol_map) && (*it).id == symId) {
-                        fc.setSymbolType((*it).type);
-                    }
-                } else if (reader.name() == QLatin1StringView("precipitation")) {
-                    fc.setPrecipitation(reader.attributes().value(QLatin1StringView("value")).toFloat());
+        case QXmlStreamReader::StartElement:
+            if (reader.name() == QLatin1StringView("temperature")) {
+                const auto t = reader.attributes().value(QLatin1StringView("value")).toFloat();
+                fc.setMinimumTemperature(t);
+                fc.setMaximumTemperature(t);
+            } else if (reader.name() == QLatin1StringView("minTemperature")) {
+                fc.setMinimumTemperature(reader.attributes().value(QLatin1StringView("value")).toFloat());
+            } else if (reader.name() == QLatin1StringView("maxTemperature")) {
+                fc.setMaximumTemperature(reader.attributes().value(QLatin1StringView("value")).toFloat());
+            } else if (reader.name() == QLatin1StringView("windSpeed")) {
+                fc.setWindSpeed(reader.attributes().value(QLatin1StringView("mps")).toFloat());
+            } else if (reader.name() == QLatin1StringView("symbol")) {
+                auto symId = reader.attributes().value(QLatin1StringView("number")).toInt();
+                if (symId > 100) {
+                    symId -= 100; // map polar night symbols
                 }
-                break;
-            case QXmlStreamReader::EndElement:
-                if (reader.name() == QLatin1StringView("time")) {
-                    return fc;
+                const auto it = std::lower_bound(std::begin(symbol_map), std::end(symbol_map), symId, [](symbol_map_t lhs, uint8_t rhs) {
+                    return lhs.id < rhs;
+                });
+                if (it != std::end(symbol_map) && (*it).id == symId) {
+                    fc.setSymbolType((*it).type);
                 }
-                break;
-            default:
-                break;
+            } else if (reader.name() == QLatin1StringView("precipitation")) {
+                fc.setPrecipitation(reader.attributes().value(QLatin1StringView("value")).toFloat());
+            }
+            break;
+        case QXmlStreamReader::EndElement:
+            if (reader.name() == QLatin1StringView("time")) {
+                return fc;
+            }
+            break;
+        default:
+            break;
         }
         reader.readNext();
     }
